// ohne Fehlerbehandlung

class Roman { // eigentlich public

	// gewaehlte Datenstruktur:
	// klassenintern werden roemische Zahlen als int-Werte verwaltet
	private int value;

	public Roman(String roman) {
		this.value = Roman.intValue(roman);
	}

	public Roman(int value) {
		this.value = value;
	}

	public Roman(Roman roman) {
		this.value = roman.value;
	}

	public String makeString() {
		return Roman.toRoman(this.value);
	}

	public boolean equals(Roman roman) {
		return this.value == roman.value;
	}

	public Roman add(Roman r) {
		this.value += r.value;
		return this;
	}

	public static Roman add(Roman r1, Roman r2) {
		return new Roman(Roman.toRoman(r1.value + r2.value));
	}

	public Roman sub(Roman r) {
		this.value -= r.value;
		return this;
	}

	public static Roman sub(Roman r1, Roman r2) {
		return new Roman(Roman.toRoman(r1.value - r2.value));
	}

	// interne Datenstruktur fuer Umrechnungszwecke
	private static String symbol = "IVXLCDM";
	private static int[] wert = { 1, 5, 10, 50, 100, 500, 1000 };

	private static int intValue(String roman) {
		int value = 0;
		// String der Reihe nach durcharbeiten
		for (int i = 0; i < roman.length(); i++) {
			// Index bestimmen
			int index1 = Roman.symbol.indexOf(roman.charAt(i));
			if (i + 1 < roman.length()) { // es folgen weitere Symbole
				int index2 = Roman.symbol.indexOf(roman.charAt(i + 1));
				if (index1 < index2) { // Differenz bilden und addieren
					value = value + Roman.wert[index2] - Roman.wert[index1];
					i++;
				} else { // addieren
					value = value + Roman.wert[index1];
				}
			} else { // letztes Symbol
				value = value + Roman.wert[index1];
			}
		}
		return value;
	}

	// interne Datenstruktur fuer Umrechnungszwecke
	private static String symbols[][] = {
			// Symbole fuer 1-9
			{ "", "I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX" },
			// Symbole fuer 10-90
			{ "", "X", "XX", "XXX", "XL", "L", "LX", "LXX", "LXXX", "XC" },
			// Symbole fuer 100-900
			{ "", "C", "CC", "CCC", "CD", "D", "DC", "DCC", "DCCC", "CM" },
			// Symbol fuer 1000
			{ "", "M", "MM", "MMM" } };

	private static String toRoman(int value) {
		String roman = new String("");
		int potenz = 0;
		while (value > 0) {
			// bestimme letzte Ziffer
			int ziffer = value % 10;
			// erweitere die Roemische Zahl entsprechend der Ziffer und der
			// aktuellen Stelligkeit
			roman = Roman.symbols[potenz][ziffer] + roman;
			// erhoehe Stelligkeit
			potenz++;
			// kuerze value um eine Stelle
			value = value / 10;
		}
		return roman;
	}
}

public class UE15Aufgabe13 {

	// Testprogramm
	public static void main(String[] args) {
		while (true) {
			int value = IO.readInt("int-Wert eingeben: ");
			Roman roman1 = new Roman(value);
			IO.println(roman1.makeString());

			String eingabe = IO.readString("Roemische Zahl eingeben: ");
			Roman roman2 = new Roman(eingabe);
			IO.println(roman2.makeString());

			Roman roman3 = Roman.add(roman1, roman2);
			IO.println("Summe: " + roman3.makeString());

			Roman roman4 = Roman.sub(roman1, roman2);
			IO.println("Differenz: " + roman4.makeString());
		}
	}

}
